@@ -1,3 +1,3 @@
 from .readmol2 import Mol2, Mol2Block
 from .readsmiles import Smiles
-from .readpdb import PDB, PartialPDB
+from .readpdb import PDB, PartialPDB, PDBBB
